@@ -89,6 +89,6 @@ class Targets(object):
                         'targetId': target_id
                         }
 
-        r = self.connection.post_request(f'targetExportJobs', json=target_export)
+        r = self.connection.post_request('targetExportJobs', json=target_export)
         logger.info(f'Created new target export job for {target_id}.')
         return r
